==> libgda-1.99.0.tar.bz2: libgda-1.99.0/libgda/sql-delimiter/parser.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     L_IDENT = 258,
     L_STRING = 259,
     L_TEXTUAL = 260,
     L_LSBRACKET = 261,
     L_RSBRACKET = 262,
     L_PNAME = 263,
     L_PTYPE = 264,
     L_PISPARAM = 265,
     L_PDESCR = 266,
     L_PNULLOK = 267,
     L_UNSPECVAL = 268,
     L_SC = 269,
     L_EQ = 270
   };
#endif
/* Tokens.  */
#define L_IDENT 258
#define L_STRING 259
#define L_TEXTUAL 260
#define L_LSBRACKET 261
#define L_RSBRACKET 262
#define L_PNAME 263
#define L_PTYPE 264
#define L_PISPARAM 265
#define L_PDESCR 266
#define L_PNULLOK 267
#define L_UNSPECVAL 268
#define L_SC 269
#define L_EQ 270




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 18 "parser.y"
typedef union YYSTYPE {
void            *v;
char            *str;
GList           *list;
GdaDelimiterParamSpec     *ps;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 75 "parser.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE gda_delimiterlval;

==> libgda-2.99.2.tar.bz2: libgda-2.99.2/libgda/sql-delimiter/parser.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     L_IDENT = 258,
     L_STRING = 259,
     L_TEXTUAL = 260,
     L_LSBRACKET = 261,
     L_RSBRACKET = 262,
     L_PNAME = 263,
     L_PTYPE = 264,
     L_PISPARAM = 265,
     L_PDESCR = 266,
     L_PNULLOK = 267,
     L_UNSPECVAL = 268,
     L_SC = 269,
     L_EQ = 270
   };
#endif
/* Tokens.  */
#define L_IDENT 258
#define L_STRING 259
#define L_TEXTUAL 260
#define L_LSBRACKET 261
#define L_RSBRACKET 262
#define L_PNAME 263
#define L_PTYPE 264
#define L_PISPARAM 265
#define L_PDESCR 266
#define L_PNULLOK 267
#define L_UNSPECVAL 268
#define L_SC 269
#define L_EQ 270




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 71 "parser.y"
{
void            *v;
char            *str;
GList           *list;
GdaDelimiterParamSpec     *ps;
}
/* Line 1529 of yacc.c.  */
#line 86 "parser.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE gda_delimiterlval;
